@@ -3,11 +3,11 @@ package DBIx::dbMan::Extension::DescribeCompleteOracle;
 use strict;
 use base 'DBIx::dbMan::Extension';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 1;
 
-sub IDENTIFICATION { return "000001-000049-000003"; }
+sub IDENTIFICATION { return "000001-000049-000004"; }
 
 sub preference { return 1000; }
 
@@ -17,7 +17,9 @@ sub handle_action {
 	my ($obj,%action) = @_;
 
 	if ($action{action} eq 'DESCRIBE' and $action{oper} eq 'complete' and $obj->{-dbi}->driver eq 'Oracle') {
-		$action{action} = 'NONE';
+		$action{action} = 'CACHE';
+		$action{cache_type} = 'describe_ora';
+
 		unless ($obj->{-dbi}->current) {
 			$obj->{-interface}->error("No current connection selected.");
 			return %action;
@@ -29,6 +31,7 @@ sub handle_action {
 		@all = map { $_->[0] } @$ret if defined $ret;
 		$sth->finish;
 		$action{list} = \@all;
+		$action{what} = 'list';
 		$action{processed} = 1;
 		return %action;
 	}
