@@ -3,11 +3,11 @@ package DBIx::dbMan::Extension::Fallback;
 use strict;
 use base 'DBIx::dbMan::Extension';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 1;
 
-sub IDENTIFICATION { return "000001-000002-000004"; }
+sub IDENTIFICATION { return "000001-000002-000005"; }
 
 sub preference { return -99999; }
 
@@ -21,7 +21,8 @@ sub handle_action {
 	# Not handled command
 	if ($action{action} eq 'COMMAND') {
 		$action{action} = 'OUTPUT';
-		$action{output} = "Unknown command (".$action{cmd}.").\n";
+		$action{output} = '';
+        $obj->{-interface}->error( "Unknown command (".$action{cmd}.")." );
 		delete $action{processed};
 	} elsif (not $action{action}) {	# internal - incorrect handling of action
 		$obj->{-interface}->print("INTERNAL: Action not correctly handled by some extension!\n");
