@@ -3,11 +3,11 @@ package DBIx::dbMan::Extension::InputFile;
 use strict;
 use base 'DBIx::dbMan::Extension';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 1;
 
-sub IDENTIFICATION { return "000001-000024-000003"; }
+sub IDENTIFICATION { return "000001-000024-000004"; }
 
 sub preference { return 0; }
 
@@ -22,6 +22,9 @@ sub handle_action {
 			$obj->{-interface}->error("Can't load input file $action{file}.");
 			return %action;
 		}
+        if ( $obj->{ -interface }->is_utf8 ) {
+            binmode F, ':utf8';   
+        }
 		while (<F>) {
 			chomp;
 			my $newaction = { action => 'COMMAND', cmd => $_ };
